diff -r b5a6f84a7ad5 -r 24f6e0b0d9e6 include/opus.h
--- a/include/opus.h	Wed Aug 31 10:55:37 2016 -0400
+++ b/include/opus.h	Wed Aug 31 11:43:03 2016 -0400
@@ -268,6 +268,15 @@
     opus_int32 max_data_bytes
 ) OPUS_ARG_NONNULL(1) OPUS_ARG_NONNULL(2) OPUS_ARG_NONNULL(4);
 
+/** Gets internal flags. To be used after <tt>opus_encode</tt>
+  * @param [in] st <tt>OpusEncoder*</tt>: Encoder state
+  * @param [out] flags <tt>opus_internal_flags*</tt>: Internal flags
+  */
+OPUS_EXPORT opus_int32 opus_encoder_get_internal_flags(
+    OpusEncoder *st,
+    opus_internal_flags *flags
+) OPUS_ARG_NONNULL(1) OPUS_ARG_NONNULL(2);
+
 /** Encodes an Opus frame from floating point input.
   * @param [in] st <tt>OpusEncoder*</tt>: Encoder state
   * @param [in] pcm <tt>float*</tt>: Input in float format (interleaved if 2 channels), with a normal range of +/-1.0.
diff -r b5a6f84a7ad5 -r 24f6e0b0d9e6 include/opus_types.h
--- a/include/opus_types.h	Wed Aug 31 10:55:37 2016 -0400
+++ b/include/opus_types.h	Wed Aug 31 11:43:03 2016 -0400
@@ -156,4 +156,10 @@
 #define opus_uint64      unsigned long long
 #define opus_uint8       unsigned char
 
+typedef struct {
+    opus_int speech_activity_Q8;
+    opus_int SNR_dB_Q7;
+    opus_int8 prevSignalType;
+} opus_internal_flags;
+
 #endif  /* OPUS_TYPES_H */
diff -r b5a6f84a7ad5 -r 24f6e0b0d9e6 src/opus_encoder.c
--- a/src/opus_encoder.c	Wed Aug 31 10:55:37 2016 -0400
+++ b/src/opus_encoder.c	Wed Aug 31 11:43:03 2016 -0400
@@ -2059,6 +2059,14 @@
 }
 #endif
 
+opus_int32 opus_encoder_get_internal_flags(OpusEncoder *st, opus_internal_flags *flags)
+{
+    silk_encoder *silk_enc = (silk_encoder*)((void*)st+st->silk_enc_offset);
+    flags->speech_activity_Q8 = silk_enc->state_Fxx[0].sCmn.speech_activity_Q8;
+    flags->SNR_dB_Q7 = silk_enc->state_Fxx[0].sCmn.SNR_dB_Q7;
+    flags->prevSignalType = silk_enc->state_Fxx[0].sCmn.prevSignalType;
+    return OPUS_OK;
+}
 
 int opus_encoder_ctl(OpusEncoder *st, int request, ...)
 {
